==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/TagImportPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class TagImportPolicyFluentImpl<A extends TagImportPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TagImportPolicyFluent<A>{

    private Boolean insecure;
    private Boolean scheduled;

    public TagImportPolicyFluentImpl(){
    }
    public TagImportPolicyFluentImpl(TagImportPolicy instance){
            this.withInsecure(instance.getInsecure()); 
            this.withScheduled(instance.getScheduled()); 
    }

    public Boolean isInsecure(){
            return this.insecure;
    }

    public A withInsecure(Boolean insecure){
            this.insecure=insecure; return (A) this;
    }

    public Boolean isScheduled(){
            return this.scheduled;
    }

    public A withScheduled(Boolean scheduled){
            this.scheduled=scheduled; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TagImportPolicyFluentImpl that = (TagImportPolicyFluentImpl) o;
            if (insecure != null ? !insecure.equals(that.insecure) :that.insecure != null) return false;
            if (scheduled != null ? !scheduled.equals(that.scheduled) :that.scheduled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.75-sources.jar: io/fabric8/openshift/api/model/TagImportPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class TagImportPolicyFluentImpl<A extends TagImportPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements TagImportPolicyFluent<A>{

    private Boolean insecure;
    private Boolean scheduled;

    public TagImportPolicyFluentImpl(){
    }
    public TagImportPolicyFluentImpl(TagImportPolicy instance){
            this.withInsecure(instance.getInsecure()); 
            this.withScheduled(instance.getScheduled()); 
    }

    public Boolean isInsecure(){
            return this.insecure;
    }

    public A withInsecure(Boolean insecure){
            this.insecure=insecure; return (A) this;
    }

    public Boolean hasInsecure(){
            return this.insecure!=null;
    }

    public Boolean isScheduled(){
            return this.scheduled;
    }

    public A withScheduled(Boolean scheduled){
            this.scheduled=scheduled; return (A) this;
    }

    public Boolean hasScheduled(){
            return this.scheduled!=null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TagImportPolicyFluentImpl that = (TagImportPolicyFluentImpl) o;
            if (insecure != null ? !insecure.equals(that.insecure) :that.insecure != null) return false;
            if (scheduled != null ? !scheduled.equals(that.scheduled) :that.scheduled != null) return false;
            return true;
    }




}
